%bcond docs 1
# tests are broken on s390x
# https://gitlab.gnome.org/jrb/crosswords/-/issues/118
%ifarch s390x
%bcond tests 0
%else
%bcond tests 1
%endif

# Disabled in preparation for the next release
%bcond thumbnailer 1

Name:           crosswords
Version:        0.3.12
Release:        1.20240419071005818033.master.367.g8e55f47a%{?dist}
Summary:        Solve crossword puzzles

# crosswords itself is GPL-3.0-or-later, the puzzle sets it bundles are
# CC-BY-SA-4.0
License:        GPL-3.0-or-later and CC-BY-SA-4.0
URL:            https://gitlab.gnome.org/jrb/crosswords
Source:         crosswords-0.3.12.tar.gz
# Listen to PickerListRow::changed instead of ModelRow::changed

BuildRequires:  desktop-file-utils
BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  libappstream-glib
BuildRequires:  meson
BuildRequires:  sed
%if %{with docs}
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(sphinx-rtd-theme)
BuildRequires:  python3dist(myst-parser)
%endif
%if %{with tests}
# gen-word-list requires en_US.UTF8
# https://gitlab.gnome.org/jrb/crosswords/-/issues/109
BuildRequires:  glibc-langpack-en
%endif

BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(libipuz-0.4)
BuildRequires:  pkgconfig(libpanel-1)
BuildRequires:  pkgconfig(librsvg-2.0)

Requires:       dbus-common
Requires:       %{name}-puzzle-sets-cats-and-dogs = %{version}-%{release}
Requires:       %{name}-puzzle-sets-uri = %{version}-%{release}
%if %{with thumbnailer}
Recommends:     %{name}-thumbnailer = %{version}-%{release}
%endif
Suggests:       crossword-editor = %{version}-%{release}
%if %{with docs}
Suggests:       %{name}-doc = %{version}-%{release}
%endif

%description
A simple and fun game of crosswords. Load your crossword files, or play one of
the included games. Features include:

- Support for shaped and colored crosswords
- Loading .ipuz and .puz files
- Hint support, such as showing mistakes and suggesting words
- Dark mode support
- Locally installed crosswords as well as support for 3rd party downloaders

%package        puzzle-sets-cats-and-dogs
Summary:        Puzzles about cats and dogs for GNOME Crosswords
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    puzzle-sets-cats-and-dogs
This package contains a puzzle set about cats and dogs for GNOME Crosswords.

%package        puzzle-sets-internal
Summary:        Load additional puzzles for GNOME Crosswords
Requires:       %{name} = %{version}-%{release}
Provides:       crosswords-puzzle-sets-uri = %{version}-%{release}
Obsoletes:      crosswords-puzzle-sets-uri < 0.3.6-3
BuildArch:      noarch

# Used to load .puz files from disk
Recommends:     ipuz-convertor = %{version}-%{release}

%description    puzzle-sets-internal
This package contains puzzle sets used internally by GNOME Crosswords to load
additional puzzles from disk.

%if %{with thumbnailer}
%package        thumbnailer
Summary:        GNOME Crosswords Thumbnailer

%description    thumbnailer
This package provides a thumbnailer for crosswords puzzles in formats supported
by GNOME Crosswords.
%endif

%if %{with docs}
%package        doc
Summary:        Documentation for %{name}
BuildArch:      noarch

%description    doc
This package contains additional documentation for GNOME Crosswords.
%endif

%package -n     crossword-editor
Summary:        Crossword puzzle editor

Requires:       %{name}%{?_isa} = %{version}-%{release}
%if %{with thumbnailer}
Recommends:     %{name}-thumbnailer = %{version}-%{release}
%endif
# Used to load .puz files from disk
Recommends:     ipuz-convertor = %{version}-%{release}

%description -n crossword-editor
Standalone-tool to create crossword puzzles based on GNOME Crosswords. It can
be used to create simple puzzles with grids and clues. It has a pattern solver
and grid autofill dialog for filling in hard-to-finish corners, and will make
suggestions of words when creating the grid.

%package -n     ipuz-convertor
Summary:        Converts puz files to ipuz files
BuildArch:      noarch

Requires:       crosswords
Requires:       python3
Requires:       python3dist(dateparser)
Requires:       python3dist(lxml)
Requires:       python3dist(puzpy)
Requires:       python3dist(regex)

%description -n ipuz-convertor
ipuz-convertor is a script to convert puzzle files from puz to ipuz.

%prep
%autosetup -p1 -n crosswords-0.3.12

# Update image references in README
mkdir images
cp -p data/images/{a-dogs-day,hero}.png images/
sed -i 's:data/images/:images/:g' README.md

%build
%meson -Ddevelopment=false
%meson_build

%if %{with docs}
sphinx-build-3 docs html
rm -rf html/.{doctrees,buildinfo}
%endif

%install
%meson_install
%find_lang %{name}

%if %{with tests}
%check
%meson_test

appstream-util validate-relax --nonet \
  %{buildroot}%{_metainfodir}/org.gnome.Crosswords.metainfo.xml

desktop-file-validate \
  %{buildroot}/%{_datadir}/applications/org.gnome.Crosswords.desktop \
  %{buildroot}/%{_datadir}/applications/org.gnome.Crosswords.Editor.desktop
%endif

%files -f %{name}.lang
%license COPYING
%doc CONTRIBUTING.md NEWS.md README.md TODO.md images
%{_bindir}/%{name}
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/puzzle-sets
%{_datadir}/applications/org.gnome.Crosswords.desktop
%{_datadir}/dbus-1/services/org.gnome.Crosswords.service
%{_datadir}/glib-2.0/schemas/org.gnome.Crosswords.gschema.xml
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Crosswords.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gnome.Crosswords-symbolic.svg
%{_datadir}/mime/packages/org.gnome.Crosswords.xml
%{_metainfodir}/org.gnome.Crosswords.metainfo.xml

%if %{with docs}
%files doc
%license COPYING
%doc html
%endif

%files puzzle-sets-cats-and-dogs
%license COPYING
%{_datadir}/%{name}/puzzle-sets/cats-and-dogs

%files puzzle-sets-internal
%license COPYING
%{_datadir}/%{name}/puzzle-sets/*
%exclude %{_datadir}/%{name}/puzzle-sets/cats-and-dogs

%if %{with thumbnailer}
%files thumbnailer
%license COPYING
%{_bindir}/%{name}-thumbnailer
%dir %{_datadir}/thumbnailers
%{_datadir}/thumbnailers/%{name}.thumbnailer
%endif

%files -n crossword-editor
%{_bindir}/crossword-editor
%{_datadir}/applications/org.gnome.Crosswords.Editor.desktop
%{_datadir}/dbus-1/services/org.gnome.Crosswords.Editor.service
%{_datadir}/glib-2.0/schemas/org.gnome.Crosswords.Editor.gschema.xml
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Crosswords.Editor.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gnome.Crosswords.Editor-symbolic.svg
%{_metainfodir}/org.gnome.Crosswords.Editor.metainfo.xml

%files -n ipuz-convertor
%license COPYING
%{_datadir}/%{name}/ipuz-convertor
%{_libexecdir}/ipuz-convertor

%changelog
* Fri Apr 19 2024 Packit <hello@packit.dev> - 0.3.12-1.20240419071005818033.master.367.g8e55f47a
- add a test for mixed filter types. (Jonathan Blandford)
- Append WordIndexes instead of gushorts to the WordArray (Jonathan Blandford)
- Update the docs for WordArray (Jonathan Blandford)
- Missed this header cleanup a few commits ago (Jonathan Blandford)
- Make the 3rd phase work (Jonathan Blandford)
- Move the FilterFragment and anagram sections to the top of the file (Jonathan Blandford)
- Clean up WordList comments (Jonathan Blandford)
- Clean up documentation for header defines (Jonathan Blandford)
- Add some tests for the fully '?' filters (Jonathan Blandford)
- Handle the empty filters for phase 1 and 2. (Jonathan Blandford)
- Turn off DEBUG_INTERSECTION in git (Jonathan Blandford)
- Refactor intersection tests to make it easier to call multiple tests (Jonathan Blandford)
- refactor the intersection loop into its own function. (Jonathan Blandford)
- Test that the intersection is what we expect for the broda list (Jonathan Blandford)
- Beginnings of a test for find_intersection() (Jonathan Blandford)
- We ignore the mode completely for now (Jonathan Blandford)
- Set up outputs for find_intersection (Jonathan Blandford)
- Initial implementation of find_intersection() (Jonathan Blandford)
- Clean up indentation (Jonathan Blandford)
- Change word_list_set_filter to use validate_filter (Jonathan Blandford)
- New function: validate_filter (Jonathan Blandford)
- Finally Define the WILDCARDS externally (Jonathan Blandford)
- minor maintenance on the word-list docs (Jonathan Blandford)
- Include xd notes field in converted puzzle (Gwyneth Morgan)
- Add a quick note about using virtualenv when playing with python (Jonathan Blandford)
- Don't hardcode the python3 path (Jonathan Blandford)
- Add --svg flag to the thumbnailer (Tanmay Patil)
- Support puz v2 files with UTF-8 encoding (Gwyneth Morgan)
- Support xd crossword puzzles (Gwyneth Morgan)
- Pass format to ipuz-convertor when known (Gwyneth Morgan)
- Fix macOS build (Vinson Lee)
- packit: enable the thumbnailer (Davide Cavalca)
- Set the GridState behavior to SHOW_GUESS if the clue grid does not contain the cursor (Tanmay Patil)
- Initialize cursor to a "invalid" coord (Tanmay Patil)
- Explicitly initialize clear_func to NULL (Jonathan Blandford)
- Temporarily disable the unused buttons if DEVELOPMENT is FALSE (Jonathan Blandford)
- Enable the histograms for crosswords (Jonathan Blandford)
- Keep the enabled/disabled widget information around (Jonathan Blandford)
- Keep the letter_historgram and cluelen_histogram Groups around (Jonathan Blandford)
- Add acrostic_details to edit_window (Jonathan Blandford)
- Centralize the initial set up in one function (Jonathan Blandford)
- Add the AcrosticDetails page to Edit Window (Jonathan Blandford)
- remove extraneous header file (Jonathan Blandford)
- EditAcrosticDetails: Add a stub for acrostic details (Jonathan Blandford)
- Add a title row (Jonathan Blandford)
- Hide arrowword and fillipine puzzles for now (Jonathan Blandford)
- disable text.redo as well as text.undo (Jonathan Blandford)
- Hook up create_button.sensitivity to the valid property of the greeter (Jonathan Blandford)
- Update the valid property in EditGreeterAcrostic (Jonathan Blandford)
- connect the creation of puzzles to the valid property (Jonathan Blandford)
- Add the "valid" property to the interface (Jonathan Blandford)
- Add a "valid" property to EditGreeterCrossword (Jonathan Blandford)
- Clean up update functions (Jonathan Blandford)
- Add a "valid" property to EditGreeterAcrostic (Jonathan Blandford)
- Fix leak of puzzle (Jonathan Blandford)
- Fix indentation (Jonathan Blandford)
- Create an acrostic on initialization (Jonathan Blandford)
- We don't need to keep the preferences_group around (Jonathan Blandford)
- Get EditGreeterAcrostic to match the crossword greeter a little more (Jonathan Blandford)
- Guard against widgets being destroyed (Jonathan Blandford)
- Add C-S-z to also redo. (Jonathan Blandford)
- Store the focused widget (Jonathan Blandford)
- Don't set the stage on the puzzle-stack object (Jonathan Blandford)
- Store the stage as part of undo/redo restoration (Jonathan Blandford)
- turn off enable-undo in all AdwEntryRows (Jonathan Blandford)
- White space cleanup (Jonathan Blandford)
- s/xword/self (Jonathan Blandford)
- Move edit-window to the new undo/redo approach (Jonathan Blandford)
- Minimise the maximum word size for quotes with short lengths (Tanmay Patil)
- Update to latest libipuz API changes (Tanmay Patil)
- Use peek_next_data to get the right stack for undo (Jonathan Blandford)
- Confusingly, the next frame conceptually is actually current->prev (Jonathan Blandford)
- Use a #define for the data strings (Jonathan Blandford)
- Push the dehydrated state in with changes (Jonathan Blandford)
- API changes (Tanmay Patil)
- Move acrostic-board-dimensios.* to libipuz (Tanmay Patil)
- slight change in function call (Tanmay Patil)
- Do not preview grid for invalid input (Tanmay Patil)
- Preview grid: display quote string on the grid (Tanmay Patil)
- Make dimensions array static (Tanmay Patil)
- Use pre-defined array of dimensions (Tanmay Patil)
- Minor changes in function calls (Tanmay Patil)
- adw_entry_row_get_text_length is unstable (Tanmay Patil)
- Add EditGreeterAcrostic widget (Tanmay Patil)
- PuzzleStack::changed → new_frame boolean to an enum (Jonathan Blandford)
- New function to centralize us pushing changes (Jonathan Blandford)
- Make STATE_DEHYDRATED public (Jonathan Blandford)
- Add puzzle_stack_peek_next_data() (Jonathan Blandford)
- Remove dead comment (Jonathan Blandford)
- Fix logic for when we can edit a cell type (Jonathan Blandford)
- en_US spellings (Jonathan Blandford)
- Fix whitespace (Jonathan Blandford)
- Add grid_state_change_behavior() (Jonathan Blandford)
- Undo bad merge from landing the edit-selection branch (Jonathan Blandford)
- Remove state->mode (Jonathan Blandford)
- Update only the behavior when we change modes of a state (Jonathan Blandford)
- Use grid_state_new_from_behavior (Jonathan Blandford)
- Add grid_state_new_from_behavior (Jonathan Blandford)
- Don't check the mode when testing States (Jonathan Blandford)
- Don't bother setting the mode (Jonathan Blandford)
- define XWORD_IN_WON_STATE in terms of behavior (Jonathan Blandford)
- Remove unused mode argument (Jonathan Blandford)
- Use behavior instead of mode (Jonathan Blandford)
- Initialize these to NULL (Jonathan Blandford)
- Initialize these to NULL (Jonathan Blandford)
- Make sure we set an inintial value (Jonathan Blandford)
- Tweak wording and UI layout (Jonathan Blandford)
- Add completion percentage label (Jonathan Blandford)
- CI: Add a job to build in release mode with -Werror (Federico Mena Quintero)
- validate_word(): Fully initialize the ValidatedWord (Federico Mena Quintero)
- gen_word_list_add_test_word(): Initialize validated.enumeration_src here as well (Federico Mena Quintero)
- gnome-languages.c: Fix uninitialized variables (Federico Mena Quintero)
- grid-layout.c: Fix uninitialized variable (Federico Mena Quintero)
- Use an intermediate script for scan-build so failures will break the build (Federico Mena Quintero)
- PlayCell: work around false positive in static-scan (Federico Mena Quintero)
- Fix test as GRID_STATE_VIEW had the wrong behavior (Jonathan Blandford)
- Historically, GRID_STATE_SELECT showed the solution not the guess (Jonathan Blandford)
- Switch writing to the GUESS vs the SOLUTION (Jonathan Blandford)
- Fix indentation (Jonathan Blandford)
- Redraw the cell when we cancel multichar (Jonathan Blandford)
- Migrate `switch (state->mode)` to behaviors (Jonathan Blandford)
- Migrate from mode to behavior (Jonathan Blandford)
- Migrate from mode to behavior (Jonathan Blandford)
- Show the histogram even if we don't have any letters (Jonathan Blandford)
- Last migration from mode to behavior (Jonathan Blandford)
- Migrate from mode to behavior (Jonathan Blandford)
- Migrate from mode to behavior (Jonathan Blandford)
- Migrate from mode to behavior (Jonathan Blandford)
- Migrate from mode to behavior (Jonathan Blandford)
- Another trailing comma in the JSON files, and make the build-options consistent (Federico Mena Quintero)
- Oh, JSON, never change. (Federico Mena Quintero)
- Fix use-after-free (static-scan) (Federico Mena Quintero)
- Fix uninitialized variables (from static-scan) (Federico Mena Quintero)
- fix whitespace (Jonathan Blandford)
- Remove duplicated "source" (Federico Mena Quintero)
- Try the incantation from Amberol instead (Federico Mena Quintero)
- Copy the incantations to build a Flatpak with Rust in it (Federico Mena Quintero)
- acrostic-generator.c: Update for IPuzCharset API changes (Federico Mena Quintero)
- GRID_STATE_CURSOR_SET is much more complicated now (Jonathan Blandford)
- Migrate from mode to behavior (Jonathan Blandford)
- gen-word-list-importer.c: Update for IPuzCharset API changes (Federico Mena Quintero)
- gen-word-list.c: Update for IPuzCharset API changes (Federico Mena Quintero)
- CI: Update the Rust installation scripts and Rust version (Federico Mena Quintero)
- Migrate from mode to behavior (Jonathan Blandford)
- Migrate from mode to behavior (Jonathan Blandford)
- s/GRID_STATE_HAS_CURSOR/GRID_STATE_CURSOR_SET/g (Jonathan Blandford)
- Add and document a new behavior: QUIRKS_ADVANCE (Jonathan Blandford)
- We only use STATE_SOLVE in these tests; hardcode it in assert_state (Jonathan Blandford)
- Compare the behavior as well (Jonathan Blandford)
- Disable no_clues and some_clues tests for now (Jonathan Blandford)
- Move #defines to the top of the file (Jonathan Blandford)
- Migrate from mode to behavior (Jonathan Blandford)
- Migrate from mode to behavior (Jonathan Blandford)
- Migrate from mode to behavior (Jonathan Blandford)
- Migrate from mode to behavior (Jonathan Blandford)
- Reflect fixes to EDIT and EDIT_BROWSE in the docs (Jonathan Blandford)
- Fix the MODE flags for EDIT and EDIT_BROWSE (Jonathan Blandford)
- grid-layout: Set editable to FALSE when Puzzle is in Browse mode (Demigod345)
- Migrate from mode to behavior (Jonathan Blandford)
- Migrate from mode to behavior (Jonathan Blandford)
- Macros to key off the current behavior (Jonathan Blandford)
- Update design doc (Jonathan Blandford)
- Set the behavior when we update the mode. (Jonathan Blandford)
- Define the modes in terms of behaviors (Jonathan Blandford)
- Clean up whitespace (Jonathan Blandford)
- Add GridStateBehavior (Jonathan Blandford)
- rename CURSOR_ONLY_NORMAL to NORMAL_ONLY (Jonathan Blandford)
- Indicate the deprecation of the old approach more firmly in the docs (Jonathan Blandford)
- Update proposal (Jonathan Blandford)
- Set default values for the test quirks object (Jonathan Blandford)
- Quick fix to make the grid stats non-homogeneous (Jonathan Blandford)
- s/quirks/self/g (Jonathan Blandford)
- Check if switch_on_move_override is set (Jonathan Blandford)
- Check whether ij_digraph_override was actually set (Jonathan Blandford)
- Only create the settings object when needed (Jonathan Blandford)
- Add test for advance on guess corner case (Adam Fontenot)
- Fix minor issue with selecting cell in advance search (Adam Fontenot)
- Refactor automatic advance on guess to use new method (Adam Fontenot)
- Add a quirks test mode (Jonathan Blandford)
- Remove rebus attribute (Jonathan Blandford)
- Only queue a redraw on the border if it actually changed (Jonathan Blandford)
- svg_handle_from_string() now takes the Coloring as an argument (Jonathan Blandford)
- Fix up whitespace (Jonathan Blandford)
- Move creation of overlay into update() (Jonathan Blandford)
- Make svg_handle_form_string public (Jonathan Blandford)
- Improve visibility of border around cluerows (Jonathan Blandford)
- Clean up whitespace (Jonathan Blandford)
- improve style guide conformance of recent changes (Adam Fontenot)
- add shortcut window info for next/prev clue actions (Adam Fontenot)
- add tests for next-empty-cell action (Adam Fontenot)
- Fix infinite loop with tab key (next empty cell) (Adam Fontenot)
- Add json_glib_dep to thumbnailer (Tanmay Patil)
- Ensure complete row is visible after scrolling (Tanmay Patil)
- Move code into if block (Tanmay Patil)
- Scroll up/down to the highlighted clue (Tanmay Patil)
- Semi-highlight the other clue of currently selected cell (Tanmay Patil)
- Change tab behavior to go to next unsolved clue (Adam Fontenot)
- The fix from !150 broke zooming from the keyboard (Jonathan Blandford)
- Start of a design for the GridState modes refactor (Jonathan Blandford)
- Render svgs to specified size (Tanmay Patil)
- play-window: Make zoom menu sensitive during game play (hariharan)
- Fix a doc (Jonathan Blandford)
- Fix a warning (Jonathan Blandford)
- Display toggle switches in ON position if activated (Tanmay Patil)
- Remove reset of last_allocated_config when updating the state (Jonathan Blandford)
- Set bg_color, not bg_color_set (Jonathan Blandford)
- remove label_set_text_to_fit (Jonathan Blandford)
- New internal functions to consolidate the text handling code (Jonathan Blandford)
- Fix Cell Style: Change label_set_text_to_fit() to return the new size (Jonathan Blandford)
- Rename PlayCell load_state to update. (Jonathan Blandford)
- Remove dead comments and code (Jonathan Blandford)
- Force a queue-resize after calling load_state() (Jonathan Blandford)
- puzzle-set: Remove game related toasts at Main page (hariharan)
- Massive cleanup. load_state is much closer to being correct. (Jonathan Blandford)
- puzzle-set:Display toast when loading invalid puzzle file (hariharan)
- Use the layout instead of the IPuzCell (Jonathan Blandford)
- puzle-set: Display toast when loading an invalid puzzle (hariharan)
- Calculate the cluenum text and location (Jonathan Blandford)
- Move the chunkifying to the struct allocation (Jonathan Blandford)
- Add shapebg to the CellLayout (Jonathan Blandford)
- Add fields that PlayCell needs to GridLayout (Jonathan Blandford)
- Use the string_chunk for main_text (Jonathan Blandford)
- remove label_set_text_to_fit (Jonathan Blandford)
- New internal functions to consolidate the text handling code (Jonathan Blandford)
- Fix Cell Style: Change label_set_text_to_fit() to return the new size (Jonathan Blandford)
- puzzle-set:Display dialog when loading invalid puzzle file (hariharan)
- Listen to PickerListRow::changed instead of ModelRow::changed (Jonathan Blandford)
- Use aliases in packit config (Davide Cavalca)
- Shrink the swatch (Jonathan Blandford)
- Unset the current color even if style is NULL (Jonathan Blandford)
- Add a boolean to indicate whether current_color is valid (Jonathan Blandford)
- use EditColorRow in EditWindow (Jonathan Blandford)
- New widget: EditColorRow (Jonathan Blandford)
- Add the togglebutton to a group (Jonathan Blandford)
- Add EditColorSwatch (Jonathan Blandford)
- Clean up #includes and indentation (Jonathan Blandford)
- Set the transition duration to 0 (Jonathan Blandford)
- Use toggle buttons for the buttons instead of regular buttons (Jonathan Blandford)
- Use g_autoptr (Tanmay Patil)
- play-window: Removes previous button on Puzzle Main page (hariharan)
- Free up memory (Tanmay Patil)
- Added nautilus thumbnailer support for mime types application/x-ipuz (Tanmay Patil)
- Put some styling in the plaque in the doghouse (Jonathan Blandford)
- Fix_styles() of the puzzle after setting it (Jonathan Blandford)
- Revers polarity of test for style_name (Jonathan Blandford)
- Update the docs (Jonathan Blandford)
- Use style_name instead of named_style (Jonathan Blandford)
- use ensure_lone_style() (Jonathan Blandford)
- Add grid_state_ensure_lone_style() (Jonathan Blandford)
- Add missing G_GNUC_WARN_UNUSED (Jonathan Blandford)
- First cut at setting a shapebg on a cell (Jonathan Blandford)
- hook up the shapebg row to Edit Window (Jonathan Blandford)
- Swap title and subtitle. (Jonathan Blandford)
- Set up a "changed" signal for the popover buttons (Jonathan Blandford)
- Add an update function to EditShapebgRow (Jonathan Blandford)
- Add the edit_shapebg_row to the EditWindow struct (Jonathan Blandford)
- Use IPuzStyleShape instead of IPuzStyleShapeEnum (Jonathan Blandford)
- Require newer version of libipuz to deal with the API break (Jonathan Blandford)
- Set the has-open-popup css style when popped up (Jonathan Blandford)
- Reenable the style stage (Jonathan Blandford)
- Use AdwToolbarView instead of GtkBox (Jonathan Blandford)
- Centralize the copyright notice into crosswords-credits (Jonathan Blandford)
- Fix some compile-time warnings (Jonathan Blandford)
- Remove unused strings from the about dialogs (Jonathan Blandford)
- Use adw_about_window_new_from_appdata() (Jonathan Blandford)
- Add the Editor metainfo file to the gresource (Jonathan Blandford)
- Use adw_about_window_new_from_appdata() (Jonathan Blandford)
- Include the Crosswords metadata file in the gresource file. (Jonathan Blandford)
- Build the data in the data dir before the sources (Jonathan Blandford)
- Forgot the <description> tag in the release info (Jonathan Blandford)
- Clear the guessed-error css class when the full row is guessed (Jonathan Blandford)
- Deprecate this doc (Jonathan Blandford)
- s/XwordState/GridState/g (Jonathan Blandford)
- Do not expose functions (Tanmay Patil)
- Ensure proper handling of errors before returning from `_set_text` (Tanmay Patil)
- Call it charset and not charset_en (Tanmay Patil)
- Fix style (Tanmay Patil)
- Make random_seed a guint32 (Tanmay Patil)
- Make charset a property (Tanmay Patil)
- Fix leaks (Tanmay Patil)
- Rename filter_input to normalise_input (Tanmay Patil)
- Move acrostic-generator.[c/h] to edit_sources/headers (Tanmay Patil)
- Fix typo (Tanmay Patil)
- Cleanup files (Tanmay Patil)
- Filter Quote and Source input strings (Tanmay Patil)
- Set max_word_size and min_word_size to desired (Tanmay Patil)
- Do not use GLOBAL word_size values (Tanmay Patil)
- Ooops (Tanmay Patil)
- Clean up tests (Tanmay Patil)
- Remove unused code for now (Tanmay Patil)
- Add random_seed as a property (Tanmay Patil)
- Do not set word_length to 0 while returning (Tanmay Patil)
- Remove SOURCE string in advance from charset (Tanmay Patil)
- Assign random lengths to clue entries beforehand (Tanmay Patil)
- Put some output on success/failure (Jonathan Blandford)
- moved counter outside of the parent_object spot (Jonathan Blandford)
- Add word_list to AcrosticGenerator (Tanmay Patil)
- Use spaces instead of tabs (Tanmay Patil)
- Remove dead code (Jonathan Blandford)
- Add some debugging (Jonathan Blandford)
- Use the word from the WordList rather than strduping it. (Jonathan Blandford)
- Disable dipolo tests for now (Tanmay Patil)
- Generate random length (Tanmay Patil)
- Fix issue in random offsets generator (Tanmay Patil)
- Make parameter writable (Tanmay Patil)
- Move tests to acrostic-generator-tests.c (Tanmay Patil)
- WIP: acrostic_generator_run (Tanmay Patil)
- Add license text (Tanmay Patil)
- Implement Acrostic Generator (Tanmay Patil)
- Add AcrosticGenerator object (Tanmay Patil)
- acrostic-generator: check if we can create an acrostic (Tanmay Patil)
